@@ -49,14 +49,14 @@ sub run {
     if (-r ($rcfile="$srv->{wwwdir}/local.rc")) {
       do "$rcfile" or $h->logconfess("run(): failed to load local config file '$rcfile': $@");
     }
-    $::dstar{corpus} ||= $srv->{dbdir};
+    $::dstar{corpus} ||= $srv->{dburl};
   }
 
   ##-- setup dbcgi object
   my $dbcgi =  DiaColloDB::WWW::CGI->new(%{$srv->{cgiArgs}//{}})
     or $h->logconfess("could not create DiaColloDB::WWW::CGI object: $!");
   $dbcgi->t_start(); ##-- re-start package-global timer (hack; this should really be object-local)
-  $dbcgi->{ttk_vars}{DIACOLLO_DBDIR} = $srv->{dbdir};
+  $dbcgi->{ttk_vars}{DIACOLLO_DBURL} = $srv->{dburl};
   $dbcgi->{ttk_vars}{dstar}{$_}      = $::dstar{$_} foreach (keys %::dstar);
   $dbcgi->fromRequest($hreq,$csock)
     or $h->logconfess("run(): failed to setup {dbcgi} object from HTTP::Request");
